Administration — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »

# Administration

This part is for installation and administration of the CubicWeb framework and instances based on that framework.

- 1. Installation and set-up of a CubicWeb environment
- 2. Creation of your first instance
- 3. Configure an instance
- 4. User interface for web site configuration
- 5. Multiple sources of data
- 6. LDAP integration
- 7. Working with a distributed client (using Pyro)
- 8. CubicWeb in Google AppEngine
- 9. Migrating cubicweb instances - benefits from a distributed architecture
- 10. Backups (mostly with postgresql)

## RQL logs

You can configure the CubicWeb instance to keep a log of the queries executed against your database. To do so, edit the configuration file of your instance `.../etc/cubicweb.d/myapp/all-in-one.conf` and uncomment the variable `query-log-file`:

    # web instance query log file
    query-log-file=/tmp/rql-myapp.log

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »